// Farsi

import { Locale } from "../locale";
export class fa implements Locale {
  atX0SecondsPastTheMinuteGt20(): string|null {
    return null;
  }
  atX0MinutesPastTheHourGt20(): string|null {
    return null;
  }
  commaMonthX0ThroughMonthX1(): string|null {
    return null;
  }
  commaYearX0ThroughYearX1(): string|null {
    return null;
  }

  use24HourTimeFormatByDefault() {
    return true;
  }

  anErrorOccuredWhenGeneratingTheExpressionD() {
    return "خطایی در نمایش توضیحات این وظیفه رخ داد. لطفا ساختار آن را بررسی کنید.";
  }
  everyMinute() {
    return "هر دقیقه";
  }
  everyHour() {
    return "هر ساعت";
  }
  atSpace() {
    return "در ";
  }
  everyMinuteBetweenX0AndX1() {
    return "هر دقیقه بین %s و %s";
  }
  at() {
    return "در";
  }
  spaceAnd() {
    return " و";
  }
  everySecond() {
    return "هر ثانیه";
  }
  everyX0Seconds() {
    return "هر %s ثانیه";
  }
  secondsX0ThroughX1PastTheMinute() {
    return "ثانیه %s تا %s دقیقه گذشته";
  }
  atX0SecondsPastTheMinute() {
    return "در %s قانیه از دقیقه گذشته";
  }
  everyX0Minutes() {
    return "هر %s دقیقه";
  }
  minutesX0ThroughX1PastTheHour() {
    return "دقیقه %s تا %s ساعت گذشته";
  }
  atX0MinutesPastTheHour() {
    return "در %s دقیقه پس از ساعت";
  }
  everyX0Hours() {
    return "هر %s ساعت";
  }
  betweenX0AndX1() {
    return "بین %s و %s";
  }
  atX0() {
    return "در %s";
  }
  commaEveryDay() {
    return ", هر روز";
  }
  commaEveryX0DaysOfTheWeek() {
    return ", هر %s روز از هفته";
  }
  commaX0ThroughX1() {
    return ", %s تا %s";
  }
  commaAndX0ThroughX1() {
    return ", و %s تا %s";
  }
  first() {
    return "اول";
  }
  second() {
    return "دوم";
  }
  third() {
    return "سوم";
  }
  fourth() {
    return "چهارم";
  }
  fifth() {
    return "پنجم";
  }
  commaOnThe() {
    return ", در ";
  }
  spaceX0OfTheMonth() {
    return " %s ماه";
  }
  lastDay() {
    return "آخرین روز";
  }
  commaOnTheLastX0OfTheMonth() {
    return ", در %s ماه";
  }
  commaOnlyOnX0() {
    return ", فقط در %s";
  }
  commaAndOnX0() {
    return ", و در %s";
  }
  commaEveryX0Months() {
    return ", هر %s ماه";
  }
  commaOnlyInX0() {
    return ", فقط در %s";
  }
  commaOnTheLastDayOfTheMonth() {
    return ", در آخرین روز ماه";
  }
  commaOnTheLastWeekdayOfTheMonth() {
    return ", در آخرین روز ماه";
  }
  commaDaysBeforeTheLastDayOfTheMonth() {
    return ", %s روز قبل از آخرین روز ماه";
  }
  firstWeekday() {
    return "اولین روز";
  }
  weekdayNearestDayX0() {
    return "روز نزدیک به روز %s";
  }
  commaOnTheX0OfTheMonth() {
    return ", در %s ماه";
  }
  commaEveryX0Days() {
    return ", هر %s روز";
  }
  commaBetweenDayX0AndX1OfTheMonth() {
    return ", بین روز %s و %s ماه";
  }
  commaOnDayX0OfTheMonth() {
    return ", در %s ماه";
  }
  commaEveryMinute() {
    return ", هر minute";
  }
  commaEveryHour() {
    return ", هر ساعت";
  }
  commaEveryX0Years() {
    return ", هر %s سال";
  }
  commaStartingX0() {
    return ", آغاز %s";
  }
  daysOfTheWeek() {
    return ["یک‌شنبه", "دوشنبه", "سه‌شنبه", "چهارشنبه", "پنج‌شنبه", "جمعه", "شنبه"];
  }
  monthsOfTheYear() {
    return ["ژانویه", "فوریه", "مارس", "آپریل", "مه", "ژوئن", "ژوئیه", "آگوست", "سپتامبر", "اکتبر", "نوامبر", "دسامبر"];
  }
}
