// Norwegian

import { Locale } from "../locale";
export class nb implements Locale {
  atX0SecondsPastTheMinuteGt20(): string|null {
    return null;
  }
  atX0MinutesPastTheHourGt20(): string|null {
    return null;
  }
  commaMonthX0ThroughMonthX1(): string|null {
    return null;
  }
  commaYearX0ThroughYearX1(): string|null {
    return null;
  }
  use24HourTimeFormatByDefault() {
    return true;
  }
  anErrorOccuredWhenGeneratingTheExpressionD() {
    return "En feil inntraff ved generering av uttrykksbeskrivelse. Sjekk cron syntaks.";
  }
  at() {
    return "Kl.";
  }
  atSpace() {
    return "Kl.";
  }
  atX0() {
    return "på %s";
  }
  atX0MinutesPastTheHour() {
    return "på %s minutter etter timen";
  }
  atX0SecondsPastTheMinute() {
    return "på %s sekunder etter minuttet";
  }
  betweenX0AndX1() {
    return "mellom %s og %s";
  }
  commaBetweenDayX0AndX1OfTheMonth() {
    return ", mellom dag %s og %s av måneden";
  }
  commaEveryDay() {
    return ", hver dag";
  }
  commaEveryX0Days() {
    return ", hver %s dag";
  }
  commaEveryX0DaysOfTheWeek() {
    return ", hver %s ukedag";
  }
  commaEveryX0Months() {
    return ", hver %s måned";
  }
  commaEveryX0Years() {
    return ", hvert %s år";
  }
  commaOnDayX0OfTheMonth() {
    return ", på dag %s av måneden";
  }
  commaOnlyInX0() {
    return ", bare i %s";
  }
  commaOnlyOnX0() {
    return ", på %s";
  }
  commaAndOnX0() {
    return ", og på %s";
  }
  commaOnThe() {
    return ", på ";
  }
  commaOnTheLastDayOfTheMonth() {
    return ", på den siste dagen i måneden";
  }
  commaOnTheLastWeekdayOfTheMonth() {
    return ", den siste ukedagen i måneden";
  }
  commaDaysBeforeTheLastDayOfTheMonth() {
    return ", %s dager før den siste dagen i måneden";
  }
  commaOnTheLastX0OfTheMonth() {
    return ", på den siste %s av måneden";
  }
  commaOnTheX0OfTheMonth() {
    return ", på den %s av måneden";
  }
  commaX0ThroughX1() {
    return ", %s til og med %s";
  }
  commaAndX0ThroughX1() {
    return ", og %s til og med %s";
  }
  everyHour() {
    return "hver time";
  }
  everyMinute() {
    return "hvert minutt";
  }
  everyMinuteBetweenX0AndX1() {
    return "Hvert minutt mellom %s og %s";
  }
  everySecond() {
    return "hvert sekund";
  }
  everyX0Hours() {
    return "hver %s time";
  }
  everyX0Minutes() {
    return "hvert %s minutt";
  }
  everyX0Seconds() {
    return "hvert %s sekund";
  }
  fifth() {
    return "femte";
  }
  first() {
    return "første";
  }
  firstWeekday() {
    return "første ukedag";
  }
  fourth() {
    return "fjerde";
  }
  minutesX0ThroughX1PastTheHour() {
    return "minuttene fra %s til og med %s etter timen";
  }
  second() {
    return "andre";
  }
  secondsX0ThroughX1PastTheMinute() {
    return "sekundene fra %s til og med %s etter minuttet";
  }
  spaceAnd() {
    return " og";
  }
  spaceX0OfTheMonth() {
    return " %s i måneden";
  }
  lastDay() {
    return "den siste dagen";
  }
  third() {
    return "tredje";
  }
  weekdayNearestDayX0() {
    return "ukedag nærmest dag %s";
  }
  commaStartingX0() {
    return ", starter %s";
  }
  daysOfTheWeek() {
    return ["søndag", "mandag", "tirsdag", "onsdag", "torsdag", "fredag", "lørdag"];
  }
  monthsOfTheYear() {
    return [
      "januar",
      "februar",
      "mars",
      "april",
      "mai",
      "juni",
      "juli",
      "august",
      "september",
      "oktober",
      "november",
      "desember",
    ];
  }
}
