// Dutch

import { Locale } from "../locale";
export class nl implements Locale {
  atX0SecondsPastTheMinuteGt20(): string|null {
    return null;
  }
  atX0MinutesPastTheHourGt20(): string|null {
    return null;
  }
  commaMonthX0ThroughMonthX1(): string|null {
    return null;
  }
  commaYearX0ThroughYearX1(): string|null {
    return null;
  }
  use24HourTimeFormatByDefault() {
    return true;
  }
  everyMinute() {
    return "elke minuut";
  }
  everyHour() {
    return "elk uur";
  }
  anErrorOccuredWhenGeneratingTheExpressionD() {
    return "Er is een fout opgetreden bij het vertalen van de gegevens. Controleer de gegevens.";
  }
  atSpace() {
    return "Om ";
  }
  everyMinuteBetweenX0AndX1() {
    return "Elke minuut tussen %s en %s";
  }
  at() {
    return "Om";
  }
  spaceAnd() {
    return " en";
  }
  everySecond() {
    return "elke seconde";
  }
  everyX0Seconds() {
    return "elke %s seconden";
  }
  secondsX0ThroughX1PastTheMinute() {
    return "seconden %s t/m %s na de minuut";
  }
  atX0SecondsPastTheMinute() {
    return "op %s seconden na de minuut";
  }
  everyX0Minutes() {
    return "elke %s minuten";
  }
  minutesX0ThroughX1PastTheHour() {
    return "minuut %s t/m %s na het uur";
  }
  atX0MinutesPastTheHour() {
    return "op %s minuten na het uur";
  }
  everyX0Hours() {
    return "elke %s uur";
  }
  betweenX0AndX1() {
    return "tussen %s en %s";
  }
  atX0() {
    return "om %s";
  }
  commaEveryDay() {
    return ", elke dag";
  }
  commaEveryX0DaysOfTheWeek() {
    return ", elke %s dagen van de week";
  }
  commaX0ThroughX1() {
    return ", %s t/m %s";
  }
  commaAndX0ThroughX1() {
    return ", en %s t/m %s";
  }
  first() {
    return "eerste";
  }
  second() {
    return "tweede";
  }
  third() {
    return "derde";
  }
  fourth() {
    return "vierde";
  }
  fifth() {
    return "vijfde";
  }
  commaOnThe() {
    return ", op de ";
  }
  spaceX0OfTheMonth() {
    return " %s van de maand";
  }
  lastDay() {
    return "de laatste dag";
  }
  commaOnTheLastX0OfTheMonth() {
    return ", op de laatste %s van de maand";
  }
  commaOnlyOnX0() {
    return ", alleen op %s";
  }
  commaAndOnX0() {
    return ", en op %s";
  }
  commaEveryX0Months() {
    return ", elke %s maanden";
  }
  commaOnlyInX0() {
    return ", alleen in %s";
  }
  commaOnTheLastDayOfTheMonth() {
    return ", op de laatste dag van de maand";
  }
  commaOnTheLastWeekdayOfTheMonth() {
    return ", op de laatste werkdag van de maand";
  }
  commaDaysBeforeTheLastDayOfTheMonth() {
    return ", %s dagen vóór de laatste dag van de maand";
  }
  firstWeekday() {
    return "eerste werkdag";
  }
  weekdayNearestDayX0() {
    return "werkdag dichtst bij dag %s";
  }
  commaOnTheX0OfTheMonth() {
    return ", op de %s van de maand";
  }
  commaEveryX0Days() {
    return ", elke %s dagen";
  }
  commaBetweenDayX0AndX1OfTheMonth() {
    return ", tussen dag %s en %s van de maand";
  }
  commaOnDayX0OfTheMonth() {
    return ", op dag %s van de maand";
  }
  commaEveryX0Years() {
    return ", elke %s jaren";
  }
  commaStartingX0() {
    return ", beginnend %s";
  }
  daysOfTheWeek() {
    return ["zondag", "maandag", "dinsdag", "woensdag", "donderdag", "vrijdag", "zaterdag"];
  }
  monthsOfTheYear() {
    return [
      "januari",
      "februari",
      "maart",
      "april",
      "mei",
      "juni",
      "juli",
      "augustus",
      "september",
      "oktober",
      "november",
      "december",
    ];
  }
}
