// Afrikaans

import { Locale } from "../locale";
export class af implements Locale {
  atX0SecondsPastTheMinuteGt20(): string|null {
    return null;
  }
  atX0MinutesPastTheHourGt20(): string|null {
    return null;
  }
  commaMonthX0ThroughMonthX1(): string|null {
    return null;
  }
  commaYearX0ThroughYearX1(): string|null {
    return ", jaar %s na %s";
  }

  use24HourTimeFormatByDefault() {
    return true;
  }

  anErrorOccuredWhenGeneratingTheExpressionD() {
    return "Daar was 'n fout om die tydsuitdrukking the genereer. Raadpleeg asb die uitdrukking formaat.";
  }
  everyMinute() {
    return "elke minuut";
  }
  everyHour() {
    return "elke uur";
  }
  atSpace() {
    return "Teen ";
  }
  everyMinuteBetweenX0AndX1() {
    return "Elke minuut tussen %s en %s";
  }
  at() {
    return "Teen";
  }
  spaceAnd() {
    return " en";
  }
  everySecond() {
    return "elke sekonde";
  }
  everyX0Seconds() {
    return "elke %s sekonde";
  }
  secondsX0ThroughX1PastTheMinute() {
    return "sekonde %s deur na %s na die minuut";
  }
  atX0SecondsPastTheMinute() {
    return "teen %s sekondes na die minuut";
  }
  everyX0Minutes() {
    return "elke %s minute";
  }
  minutesX0ThroughX1PastTheHour() {
    return "minute %s deur na %s na die uur";
  }
  atX0MinutesPastTheHour() {
    return "teen %s minute na die uur";
  }
  everyX0Hours() {
    return "elke %s ure";
  }
  betweenX0AndX1() {
    return "tussen %s en %s";
  }
  atX0() {
    return "teen %s";
  }
  commaEveryDay() {
    return ", elke dag";
  }
  commaEveryX0DaysOfTheWeek() {
    return ", elke %s dae van die week";
  }
  commaX0ThroughX1() {
    return ", %s deur na %s";
  }
  commaAndX0ThroughX1() {
    return ", en %s deur na %s";
  }
  first() {
    return "eerste";
  }
  second() {
    return "tweede";
  }
  third() {
    return "derde";
  }
  fourth() {
    return "vierde";
  }
  fifth() {
    return "vyfde";
  }
  commaOnThe() {
    return ", op die ";
  }
  spaceX0OfTheMonth() {
    return " %s van die maand";
  }
  lastDay() {
    return "die laaste dag";
  }
  commaOnTheLastX0OfTheMonth() {
    return ", op die laaste %s van die maand";
  }
  commaOnlyOnX0() {
    return ", net op %s";
  }
  commaAndOnX0() {
    return ", en op %s";
  }
  commaEveryX0Months() {
    return ", elke %s maande";
  }
  commaOnlyInX0() {
    return ", net in %s";
  }
  commaOnTheLastDayOfTheMonth() {
    return ", op die laaste dag van die maand";
  }
  commaOnTheLastWeekdayOfTheMonth() {
    return ", op die laaste weeksdag van die maand";
  }
  commaDaysBeforeTheLastDayOfTheMonth() {
    return ", %s dae voor die laaste dag van die maand";
  }
  firstWeekday() {
    return "eerste weeksdag";
  }
  weekdayNearestDayX0() {
    return "weeksdag naaste aan dag %s";
  }
  commaOnTheX0OfTheMonth() {
    return ", op die %s van die maande";
  }
  commaEveryX0Days() {
    return ", elke %s dae";
  }
  commaBetweenDayX0AndX1OfTheMonth() {
    return ", tussen dag %s en %s van die maand";
  }
  commaOnDayX0OfTheMonth() {
    return ", op dag %s van die maand";
  }
  commaEveryHour() {
    return ", elke uur";
  }
  commaEveryX0Years() {
    return ", elke %s jare";
  }
  commaStartingX0() {
    return ", beginnende %s";
  }
  daysOfTheWeek() {
    return ["Sondag", "Maandag", "Dinsdag", "Woensdag", "Donderdag", "Vrydag", "Saterdag"];
  }
  monthsOfTheYear() {
    return [
      "Januarie",
      "Februarie",
      "Maart",
      "April",
      "Mei",
      "Junie",
      "Julie",
      "Augustus",
      "September",
      "Oktober",
      "November",
      "Desember",
    ];
  }
}
