// English

import { Locale } from "../locale";
export class th implements Locale {
  atX0SecondsPastTheMinuteGt20(): string | null {
    return null;
  }
  atX0MinutesPastTheHourGt20(): string | null {
    return null;
  }
  commaMonthX0ThroughMonthX1(): string | null {
    return null;
  }
  commaYearX0ThroughYearX1(): string | null {
    return null;
  }

  use24HourTimeFormatByDefault() {
    return false;
  }

  anErrorOccuredWhenGeneratingTheExpressionD() {
    return "เกิดข้อผิดพลาดขณะสร้างคำอธิบายนิพจน์ ตรวจสอบไวยากรณ์นิพจน์ครอน";
  }
  everyMinute() {
    return "ทุกๆ นาที";
  }
  everyHour() {
    return "ทุกๆ ชั่วโมง";
  }
  atSpace() {
    return "เมื่อ ";
  }
  everyMinuteBetweenX0AndX1() {
    return "ทุกๆ นาที %s และ %s";
  }
  at() {
    return "เมื่อ";
  }
  spaceAnd() {
    return " และ";
  }
  everySecond() {
    return "ทุกๆ วินาที";
  }
  everyX0Seconds() {
    return "ทุกๆ %s วินาที";
  }
  secondsX0ThroughX1PastTheMinute() {
    return "วินาที %s ถึง %s นาทีที่ผ่านมา";
  }
  atX0SecondsPastTheMinute() {
    return "เมื่อ %s วินาที นาทีที่ผ่านมา";
  }
  everyX0Minutes() {
    return "ทุกๆ %s นาที";
  }
  minutesX0ThroughX1PastTheHour() {
    return "นาที %s ถึง %s ชั่วโมงที่ผ่านมา";
  }
  atX0MinutesPastTheHour() {
    return "เมื่อ %s นาที ชั่วโมงที่ผ่านมา";
  }
  everyX0Hours() {
    return "ทุกๆ %s ชั่วโมง";
  }
  betweenX0AndX1() {
    return "ระหว่าง %s ถึง %s";
  }
  atX0() {
    return "เมื่อ %s";
  }
  commaEveryDay() {
    return ", ทุกๆ วัน";
  }
  commaEveryX0DaysOfTheWeek() {
    return ", ทุกๆ %s วันของสัปดาห์";
  }
  commaX0ThroughX1() {
    return ", %s ถึง %s";
  }
  commaAndX0ThroughX1() {
    return ", %s ถึง %s";
  }
  first() {
    return "แรก";
  }
  second() {
    return "ที่สอง";
  }
  third() {
    return "ที่สาม";
  }
  fourth() {
    return "ที่สี่";
  }
  fifth() {
    return "ที่ห้า";
  }
  commaOnThe() {
    return ", ในวัน ";
  }
  spaceX0OfTheMonth() {
    return " %s ของเดือน";
  }
  lastDay() {
    return "วันสุดท้าย";
  }
  commaOnTheLastX0OfTheMonth() {
    return ", ณ สุดท้าย %s ของเดือน";
  }
  commaOnlyOnX0() {
    return ", เท่านั้น %s";
  }
  commaAndOnX0() {
    return ", และใน %s";
  }
  commaEveryX0Months() {
    return ", ทุกๆ %s เดือน";
  }
  commaOnlyInX0() {
    return ", เท่านั้น %s";
  }
  commaOnTheLastDayOfTheMonth() {
    return ", ในวันสิ้นเดือน";
  }
  commaOnTheLastWeekdayOfTheMonth() {
    return ", ในวันธรรมดาสุดท้ายของเดือน";
  }
  commaDaysBeforeTheLastDayOfTheMonth() {
    return ", %s วันก่อนวันสุดท้ายของเดือน";
  }
  firstWeekday() {
    return "วันธรรมดาวันแรก";
  }
  weekdayNearestDayX0() {
    return "วันธรรมดาที่ใกล้ที่สุด %s";
  }
  commaOnTheX0OfTheMonth() {
    return ", ในวัน %s ของเดือน";
  }
  commaEveryX0Days() {
    return ", ทุกๆ %s วัน";
  }
  commaBetweenDayX0AndX1OfTheMonth() {
    return ", ระหว่างวัน %s และ %s ของเดือน";
  }
  commaOnDayX0OfTheMonth() {
    return ", ในวัน %s ของเดือน";
  }
  commaEveryHour() {
    return ", ทุกๆ ชั่วโมง";
  }
  commaEveryX0Years() {
    return ", ทุกๆ %s ปี";
  }
  commaStartingX0() {
    return ", เริ่ม %s";
  }
  daysOfTheWeek() {
    return ["วันอาทิตย์", "วันจันทร์", "วันอังคาร", "วันพุธ", "วันพฤหัสบดี", "วันศุกร์", "วันเสาร์"];
  }
  monthsOfTheYear() {
    return [
      "มกราคม",
      "กุมภาพันธ์",
      "มีนาคม",
      "เมษายน",
      "พฤษภาคม",
      "มิถุนายน",
      "กรกฎาคม",
      "สิงหาคม",
      "กันยายน",
      "ตุลาคม",
      "พฤศจิกายน",
      "ธันวาคม",
    ];
  }
}
