// Czech

import { Locale } from "../locale";
export class sk implements Locale {
  atX0SecondsPastTheMinuteGt20(): string|null {
    return null;
  }
  atX0MinutesPastTheHourGt20(): string|null {
    return null;
  }
  commaMonthX0ThroughMonthX1(): string|null {
    return null;
  }
  commaYearX0ThroughYearX1(): string|null {
    return null;
  }

  use24HourTimeFormatByDefault() {
    return true;
  }

  anErrorOccuredWhenGeneratingTheExpressionD() {
    return "Pri vytváraní popisu došlo k chybe. Skontrolujte prosím správnosť syntaxe cronu.";
  }
  everyMinute() {
    return "každú minútu";
  }
  everyHour() {
    return "každú hodinu";
  }
  atSpace() {
    return "V ";
  }
  everyMinuteBetweenX0AndX1() {
    return "Každú minútu medzi %s a %s";
  }
  at() {
    return "V";
  }
  spaceAnd() {
    return " a";
  }
  everySecond() {
    return "každú sekundu";
  }
  everyX0Seconds() {
    return "každých %s sekúnd";
  }
  secondsX0ThroughX1PastTheMinute() {
    return "sekundy od %s do %s";
  }
  atX0SecondsPastTheMinute() {
    return "v %s sekúnd";
  }
  everyX0Minutes() {
    return "každých %s minút";
  }
  minutesX0ThroughX1PastTheHour() {
    return "minúty od %s do %s";
  }
  atX0MinutesPastTheHour() {
    return "v %s minút";
  }
  everyX0Hours() {
    return "každých %s hodín";
  }
  betweenX0AndX1() {
    return "medzi %s a %s";
  }
  atX0() {
    return "v %s";
  }
  commaEveryDay() {
    return ", každý deň";
  }
  commaEveryX0DaysOfTheWeek() {
    return ", každých %s dní v týždni";
  }
  commaX0ThroughX1() {
    return ", od %s do %s";
  }
  commaAndX0ThroughX1() {
    return ", a od %s do %s";
  }
  first() {
    return "prvý";
  }
  second() {
    return "druhý";
  }
  third() {
    return "tretí";
  }
  fourth() {
    return "štvrtý";
  }
  fifth() {
    return "piaty";
  }
  commaOnThe() {
    return ", ";
  }
  spaceX0OfTheMonth() {
    return " %s v mesiaci";
  }
  lastDay() {
    return "posledný deň";
  }
  commaOnTheLastX0OfTheMonth() {
    return ", posledný %s v mesiaci";
  }
  commaOnlyOnX0() {
    return ", iba v %s";
  }
  commaAndOnX0() {
    return ", a v %s";
  }
  commaEveryX0Months() {
    return ", každých %s mesiacov";
  }
  commaOnlyInX0() {
    return ", iba v %s";
  }
  commaOnTheLastDayOfTheMonth() {
    return ", posledný deň v mesiaci";
  }
  commaOnTheLastWeekdayOfTheMonth() {
    return ", posledný pracovný deň v mesiaci";
  }
  commaDaysBeforeTheLastDayOfTheMonth() {
    return ", %s dní pred posledným dňom v mesiaci";
  }
  firstWeekday() {
    return "prvý pracovný deň";
  }
  weekdayNearestDayX0() {
    return "pracovný deň najbližšie %s. dňu";
  }
  commaOnTheX0OfTheMonth() {
    return ", v %s v mesiaci";
  }
  commaEveryX0Days() {
    return ", každých %s dní";
  }
  commaBetweenDayX0AndX1OfTheMonth() {
    return ", medzi dňami %s a %s v mesiaci";
  }
  commaOnDayX0OfTheMonth() {
    return ", %s. deň v mesiaci";
  }
  commaEveryX0Years() {
    return ", každých %s rokov";
  }
  commaStartingX0() {
    return ", začínajúcich %s";
  }
  daysOfTheWeek() {
    return ["Nedeľa", "Pondelok", "Utorok", "Streda", "Štvrtok", "Piatok", "Sobota"];
  }
  monthsOfTheYear() {
    return [
      "Január",
      "Február",
      "Marec",
      "Apríl",
      "Máj",
      "Jún",
      "Júl",
      "August",
      "September",
      "Október",
      "November",
      "December",
    ];
  }
}
