// Chinese (Traditional)

import { Locale } from "../locale";
export class zh_TW implements Locale {
  atX0SecondsPastTheMinuteGt20(): string|null {
    return null;
  }
  atX0MinutesPastTheHourGt20(): string|null {
    return null;
  }
  commaMonthX0ThroughMonthX1(): string|null {
    return null;
  }
  commaYearX0ThroughYearX1(): string|null {
    return ", 從 %s 年至 %s 年";
  }
  use24HourTimeFormatByDefault() {
    return true;
  }
  everyMinute() {
    return "每分鐘";
  }
  everyHour() {
    return "每小時";
  }
  anErrorOccuredWhenGeneratingTheExpressionD() {
    return "產生表達式描述時發生了錯誤，請檢查 cron 表達式語法。";
  }
  atSpace() {
    return "在 ";
  }
  everyMinuteBetweenX0AndX1() {
    return "在 %s 和 %s 之間的每分鐘";
  }
  at() {
    return "在";
  }
  spaceAnd() {
    return " 和";
  }
  everySecond() {
    return "每秒";
  }
  everyX0Seconds() {
    return "每 %s 秒";
  }
  secondsX0ThroughX1PastTheMinute() {
    return "在一分鐘後的 %s 到 %s 秒";
  }
  atX0SecondsPastTheMinute() {
    return "在一分鐘後的 %s 秒";
  }
  everyX0Minutes() {
    return "每 %s 分鐘";
  }
  minutesX0ThroughX1PastTheHour() {
    return "在整點後的 %s 到 %s 分鐘";
  }
  atX0MinutesPastTheHour() {
    return "在整點後的 %s 分";
  }
  everyX0Hours() {
    return "每 %s 小時";
  }
  betweenX0AndX1() {
    return "在 %s 和 %s 之間";
  }
  atX0() {
    return "在 %s";
  }
  commaEveryDay() {
    return ", 每天";
  }
  commaEveryX0DaysOfTheWeek() {
    return ", 每週的每 %s 天";
  }
  commaX0ThroughX1() {
    return ", %s 到 %s";
  }
  commaAndX0ThroughX1() {
    return ", 和 %s 到 %s";
  }
  first() {
    return "第一個";
  }
  second() {
    return "第二個";
  }
  third() {
    return "第三個";
  }
  fourth() {
    return "第四個";
  }
  fifth() {
    return "第五個";
  }
  commaOnThe() {
    return ", 在每月 ";
  }
  spaceX0OfTheMonth() {
    return "%s ";
  }
  lastDay() {
    return "最後一天";
  }
  commaOnTheLastX0OfTheMonth() {
    return ", 每月的最後一個 %s ";
  }
  commaOnlyOnX0() {
    return ", 僅在 %s";
  }
  commaAndOnX0() {
    return ", 或 %s";
  }
  commaEveryX0Months() {
    return ", 每 %s 月";
  }
  commaOnlyInX0() {
    return ", 僅在 %s";
  }
  commaOnlyInMonthX0() {
    return ", 僅在 %s";
  }
  commaOnlyInYearX0() {
    return ", 僅在 %s 年";
  }
  commaOnTheLastDayOfTheMonth() {
    return ", 每月的最後一天";
  }
  commaOnTheLastWeekdayOfTheMonth() {
    return ", 每月的最後一個工作日";
  }
  commaDaysBeforeTheLastDayOfTheMonth() {
    return ", %s 這個月的最後一天的前幾天";
  }
  firstWeekday() {
    return "第一個工作日";
  }
  weekdayNearestDayX0() {
    return "最接近 %s 號的工作日";
  }
  commaOnTheX0OfTheMonth() {
    return ", 每月的 %s ";
  }
  commaEveryX0Days() {
    return ", 每 %s 天";
  }
  commaBetweenDayX0AndX1OfTheMonth() {
    return ", 在每月的 %s 和 %s 之間";
  }
  commaOnDayX0OfTheMonth() {
    return ", 每月的 %s";
  }
  commaEveryX0Years() {
    return ", 每 %s 年";
  }
  commaStartingX0() {
    return ", %s 開始";
  }
  dayX0() {
    return " %s 號";
  }
  daysOfTheWeek() {
    return ["星期日", "星期一", "星期二", "星期三", "星期四", "星期五", "星期六"];
  }
  monthsOfTheYear() {
    return ["一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月"];
  }
}
