// Belarus

import { Locale } from "../locale";
export class be implements Locale {
  atX0SecondsPastTheMinuteGt20(): string|null {
    return null;
  }
  atX0MinutesPastTheHourGt20(): string|null {
    return null;
  }
  commaMonthX0ThroughMonthX1(): string|null {
    return null;
  }
  commaYearX0ThroughYearX1(): string|null {
    return null;
  }
  use24HourTimeFormatByDefault() {
    return false;
  }
  everyMinute() {
    return "кожную хвіліну";
  }
  everyHour() {
    return "кожную гадзіну";
  }
  anErrorOccuredWhenGeneratingTheExpressionD() {
    return "Адбылася памылка падчас генерацыі апісання выразы. Праверце сінтаксіс крон-выразы.";
  }
  atSpace() {
    return "У ";
  }
  everyMinuteBetweenX0AndX1() {
    return "Кожную хвіліну з %s да %s";
  }
  at() {
    return "У";
  }
  spaceAnd() {
    return " і";
  }
  everySecond() {
    return "кожную секунду";
  }
  everyX0Seconds() {
    return "кожныя %s секунд";
  }
  secondsX0ThroughX1PastTheMinute() {
    return "секунды з %s па %s";
  }
  atX0SecondsPastTheMinute() {
    return "у %s секунд";
  }
  everyX0Minutes() {
    return "кожныя %s хвілін";
  }
  minutesX0ThroughX1PastTheHour() {
    return "хвіліны з %s па %s";
  }
  atX0MinutesPastTheHour() {
    return "у %s хвілін";
  }
  everyX0Hours() {
    return "кожныя %s гадзін";
  }
  betweenX0AndX1() {
    return "з %s па %s";
  }
  atX0() {
    return "у %s";
  }
  commaEveryDay() {
    return ", кожны дзень";
  }
  commaEveryX0DaysOfTheWeek() {
    return ", кожныя %s дзён тыдня";
  }
  commaX0ThroughX1() {
    return ", %s па %s";
  }
  commaAndX0ThroughX1() {
    return ", і %s па %s";
  }
  first() {
    return "першы";
  }
  second() {
    return "другі";
  }
  third() {
    return "трэці";
  }
  fourth() {
    return "чацвёрты";
  }
  fifth() {
    return "пяты";
  }
  commaOnThe() {
    return ", у ";
  }
  spaceX0OfTheMonth() {
    return " %s месяца";
  }
  lastDay() {
    return "апошні дзень";
  }
  commaOnTheLastX0OfTheMonth() {
    return ", у апошні %s месяца";
  }
  commaOnlyOnX0() {
    return ", толькі ў %s";
  }
  commaAndOnX0() {
    return ", і ў %s";
  }
  commaEveryX0Months() {
    return ", кожныя %s месяцаў";
  }
  commaOnlyInX0() {
    return ", толькі ў %s";
  }
  commaOnTheLastDayOfTheMonth() {
    return ", у апошні дзень месяца";
  }
  commaOnTheLastWeekdayOfTheMonth() {
    return ", у апошні будні дзень месяца";
  }
  commaDaysBeforeTheLastDayOfTheMonth() {
    return ", %s дзён да апошняга дня месяца";
  }
  firstWeekday() {
    return "першы будны дзень";
  }
  weekdayNearestDayX0() {
    return "найбліжэйшы будны дзень да %s";
  }
  commaOnTheX0OfTheMonth() {
    return ", у %s месяцы";
  }
  commaEveryX0Days() {
    return ", кожныя %s дзён";
  }
  commaBetweenDayX0AndX1OfTheMonth() {
    return ", з %s па %s лік месяца";
  }
  commaOnDayX0OfTheMonth() {
    return ", у %s лік месяца";
  }
  commaEveryX0Years() {
    return ", кожныя %s гадоў";
  }
  commaStartingX0() {
    return ", пачатак %s";
  }
  daysOfTheWeek() {
    return ["нядзеля", "панядзелак", "аўторак", "серада", "чацвер", "пятніца", "субота"];
  }
  monthsOfTheYear() {
    return [
      "студзень",
      "люты",
      "сакавік",
      "красавік",
      "травень",
      "чэрвень",
      "ліпень",
      "жнівень",
      "верасень",
      "кастрычнік",
      "лістапад",
      "снежань",
    ];
  }
}
