// English

import { Locale } from "../locale";
export class vi implements Locale {
  atX0SecondsPastTheMinuteGt20(): string|null {
    return null;
  }
  atX0MinutesPastTheHourGt20(): string|null {
    return null;
  }
  commaMonthX0ThroughMonthX1(): string|null {
    return null;
  }
  commaYearX0ThroughYearX1(): string|null {
    return null;
  }

  use24HourTimeFormatByDefault() {
    return true;
  }

  anErrorOccuredWhenGeneratingTheExpressionD() {
    return "Đã xảy ra lỗi khi tạo mô tả biểu thức. Vui lòng kiểm tra cú pháp biểu thức cron.";
  }
  everyMinute() {
    return "mỗi phút";
  }
  everyHour() {
    return "mỗi giờ";
  }
  atSpace() {
    return "Vào ";
  }
  everyMinuteBetweenX0AndX1() {
    return "Mỗi phút giữa %s and %s";
  }
  at() {
    return "Vào";
  }
  spaceAnd() {
    return " và";
  }
  everySecond() {
    return "mỗi giây";
  }
  everyX0Seconds() {
    return "mỗi %s giây";
  }
  secondsX0ThroughX1PastTheMinute() {
    return "giây thứ %s qua phút thứ %s";
  }
  atX0SecondsPastTheMinute() {
    return "tại giây thứ %s của mỗi phút";
  }
  everyX0Minutes() {
    return "mỗi %s phút";
  }
  minutesX0ThroughX1PastTheHour() {
    return "phút thứ %s qua %s tiếng";
  }
  atX0MinutesPastTheHour() {
    return "vào %s phút của mỗi tiếng";
  }
  everyX0Hours() {
    return "mỗi %s tiếng";
  }
  betweenX0AndX1() {
    return "giữa %s và %s";
  }
  atX0() {
    return "vào %s";
  }
  commaEveryDay() {
    return ", mỗi ngày";
  }
  commaEveryX0DaysOfTheWeek() {
    return ", mỗi %s ngày trong tuần";
  }
  commaX0ThroughX1() {
    return ", %s đến %s";
  }
  commaAndX0ThroughX1() {
    return ", %s đến %s";
  }
  first() {
    return "đầu tiên";
  }
  second() {
    return "thứ 2";
  }
  third() {
    return "thứ 3";
  }
  fourth() {
    return "thứ 4";
  }
  fifth() {
    return "thứ 5";
  }
  commaOnThe() {
    return ", trên ";
  }
  spaceX0OfTheMonth() {
    return " %s của tháng";
  }
  lastDay() {
    return "ngày cuối cùng";
  }
  commaOnTheLastX0OfTheMonth() {
    return ", vào ngày %s cuối cùng của tháng";
  }
  commaOnlyOnX0() {
    return ", chỉ trên %s";
  }
  commaAndOnX0() {
    return ", và hơn %s";
  }
  commaEveryX0Months() {
    return ", mỗi ngày %s tháng";
  }
  commaOnlyInX0() {
    return ", chỉ trong %s";
  }
  commaOnTheLastDayOfTheMonth() {
    return ", vào ngày cuối cùng của tháng";
  }
  commaOnTheLastWeekdayOfTheMonth() {
    return ", vào ngày cuối tuần của tháng";
  }
  commaDaysBeforeTheLastDayOfTheMonth() {
    return ", %s ngày trước ngày cuối cùng của tháng";
  }
  firstWeekday() {
    return "ngày đầu tuần";
  }
  weekdayNearestDayX0() {
    return "ngày trong tuần ngày gần nhất %s";
  }
  commaOnTheX0OfTheMonth() {
    return ", vào ngày %s của tháng";
  }
  commaEveryX0Days() {
    return ", mỗi %s ngày";
  }
  commaBetweenDayX0AndX1OfTheMonth() {
    return ", giữa ngày %s và %s trong tháng";
  }
  commaOnDayX0OfTheMonth() {
    return ", vào %s ngày trong tháng";
  }
  commaEveryHour() {
    return ", mỗi tiếng";
  }
  commaEveryX0Years() {
    return ", mỗi %s năm";
  }
  commaStartingX0() {
    return ", bắt đầu %s";
  }
  daysOfTheWeek() {
    return ["Chủ nhật", "Thứ 2", "Thứ 3", "Thứ 4", "Thứ 5", "Thứ 6", "Thứ 7"];
  }
  monthsOfTheYear() {
    return [
      "Tháng 1",
      "Tháng 2",
      "Tháng 3",
      "Tháng 4",
      "Tháng 5",
      "Tháng 6",
      "Tháng 7",
      "Tháng 8",
      "Tháng 9",
      "Tháng 10",
      "Tháng 11",
      "Tháng 12",
    ];
  }
}
