export { en } from "./locales/en"; // English
export { da } from "./locales/da"; // Danish
export { de } from "./locales/de"; // German
export { es } from "./locales/es"; // Spanish
export { fr } from "./locales/fr"; // French
export { it } from "./locales/it"; // Italian
export { id } from "./locales/id"; // Indonesia
export { ko } from "./locales/ko"; // Korean
export { nl } from "./locales/nl"; // Dutch
export { nb } from "./locales/nb"; // Norwegian
export { sv } from "./locales/sv"; // Swedish
export { pl } from "./locales/pl"; // Polish
export { pt_BR } from "./locales/pt_BR"; // Portuguese (Brazil)
export { pt_PT } from "./locales/pt_PT"; // Portuguese (Portugal)
export { ro } from "./locales/ro"; // Romanian
export { ru } from "./locales/ru"; // Russian
export { tr } from "./locales/tr"; // Turkish
export { uk } from "./locales/uk"; // Ukrainian
export { zh_CN } from "./locales/zh_CN"; // Chinese (Simplified)
export { zh_TW } from "./locales/zh_TW"; // Chinese (Traditional)
export { ja } from "./locales/ja";
export { he } from "./locales/he"; // Hebrew
export { cs } from "./locales/cs"; // Czech
export { sk } from "./locales/sk"; // Slovakian
export { fi } from "./locales/fi";
export { sl } from "./locales/sl"; // Slovenian
export { sw } from "./locales/sw"; // Swahili
export { fa } from "./locales/fa"; // Farsi
export { ca } from "./locales/ca"; // Catalan
export { be } from "./locales/be"; // Be
export { hu } from "./locales/hu"; // Hungarian
export { af } from "./locales/af"; // Afrikaans
export { th } from "./locales/th"; // Thai
export { ar } from './locales/ar'; // Arabic
export { vi } from './locales/vi'; // Vietnamese
export { my } from './locales/my'; // Malay
export { bg } from './locales/bg'; // Bulgarian
